/*  $Id: mcs_client.h 4135 2004-09-13 20:31:39Z jasper $
 *
 *  Copyright 2002-2004 Jasper Huijsmans <jasper@xfce.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __XFCE_MCSCLIENT_H
#define __XFCE_MCSCLIENT_H

#include <gmodule.h>

G_MODULE_IMPORT void mcs_watch_xfce_channel (void);

G_MODULE_IMPORT void mcs_stop_watch (void);

G_MODULE_IMPORT void mcs_dialog (const char *channel);

#endif /* __XFCE_MCSCLIENT_H */
